#
# spec file for package libp11
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libp11
Version:        0.2.8
Release:        10.5
Url:            http://www.opensc-project.org/libp11/
Summary:        Library Implementing a Small Layer on Top of PKCS#11 API
License:        LGPL-2.1+
Group:          Productivity/Security
Source:         %{name}-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
Source2:        baselibs.conf
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  libtool
BuildRequires:  openssl-devel
BuildRequires:  pkg-config
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Libp11 is a library implementing a small layer on top of PKCS#11 API to
make using PKCS#11 implementations easier.

The official name for PKCS#11 is "RSA Security Inc. PKCS #11
Cryptographic Token Interface (Cryptoki)".

Libp11 source code includes the official header files (version 2.20)
and thus is "derived from the RSA Security Inc. PKCS #11 Cryptographic
Token Interface (Cryptoki)".

%package -n libp11-2
Summary:        Library Implementing a Small Layer on Top of PKCS#11 API
Group:          Productivity/Security

%description -n libp11-2
Libp11 is a library implementing a small layer on top of PKCS#11 API to
make using PKCS#11 implementations easier.

The official name for PKCS#11 is "RSA Security Inc. PKCS #11
Cryptographic Token Interface (Cryptoki)".

Libp11 source code includes the official header files (version 2.20)
and thus is "derived from the RSA Security Inc. PKCS #11 Cryptographic
Token Interface (Cryptoki)".

%package devel
Summary:        Library Implementing a Small Layer on Top of PKCS#11 API
Group:          Development/Libraries/C and C++
Requires:       libp11-2 = %{version}
Requires:       openssl-devel

%description devel
Libp11 is a library implementing a small layer on top of PKCS#11 API to
make using PKCS#11 implementations easier.

The official name for PKCS#11 is "RSA Security Inc. PKCS #11
Cryptographic Token Interface (Cryptoki)".

Libp11 source code include the official header files (version 2.20) and
thus is "derived from the RSA Security Inc. PKCS #11 Cryptographic
Token Interface (Cryptoki)".

%prep
%setup -q
tr -d \\r <doc/nonpersistent/wiki.out/trac.css >doc/nonpersistent/wiki.out/trac.css.unix
touch -r doc/nonpersistent/wiki.out/trac.css doc/nonpersistent/wiki.out/trac.css.unix
mv doc/nonpersistent/wiki.out/trac.css.unix doc/nonpersistent/wiki.out/trac.css

%build
%if %suse_version > 1100
autoreconf -f -i
%endif
%configure --disable-static --with-pic \
	--enable-doc\
	--docdir=%{_docdir}/libp11-2\
	--enable-api-doc\
	--with-apidocdir=%{_docdir}/%{name}-devel
make %{?jobs:-j%jobs}

%install
%makeinstall
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name} $RPM_BUILD_ROOT%{_docdir}/libp11-2
rm -f %{buildroot}%{_libdir}/*.la
%fdupes %{buildroot}%{_docdir}

%clean
rm -rf $RPM_BUILD_ROOT

%post -n libp11-2 -p /sbin/ldconfig

%postun -n libp11-2 -p /sbin/ldconfig

%files -n libp11-2
%defattr (-, root, root)
%doc %{_docdir}/libp11-2
%{_libdir}/*.so.*

%files devel
%defattr (-, root, root)
%doc %{_docdir}/%{name}-devel
%{_includedir}/*.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Tue Sep 25 2012 sbrabec@suse.cz
- Update to version 0.2.8:
  * Bumped soname for PKCS11_token struct size changes.
  * Display the number of available slots.
  * Expose more token flags in PKCS11_token structure.
  * Check that private data is not NULL in pkcs11_release_slot.
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Jan 11 2011 sbrabec@suse.cz
-  Updated to version 0.2.7:
  * Ignore CKR_CRYPTOKI_ALREADY_INITIALIZED while initializing.
* Mon Feb  1 2010 jengelh@medozas.de
- Package baselibs.conf
* Wed Aug  5 2009 sbrabec@suse.cz
- Updated to version 0.2.6:
  * Add new symbol to export file.
  * Add function to export the slot id.
  * Increase library version because of the new function.
* Wed Apr  8 2009 sbrabec@suse.cz
- Don't call autoreconf on older products.
* Tue Sep  2 2008 sbrabec@suse.cz
- Call autoreconf to build correctly with new libtool.
* Tue Sep  2 2008 crrodriguez@suse.de
- fix build, doxygen required.
- kill ".la" files and static libraries
- fix -devel package requires
* Tue Aug 19 2008 sbrabec@suse.cz
- Updated to version 0.2.4:
  * Build system rewritten
  * added PKCS11_CTX_init_args
  * fix segfault in init_args code
  * implemented PKCS11_private_encrypt
- Fixed incorrect API.
- Fixed x86_64 issues.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Mon Jul 30 2007 ro@suse.de
- provide old name
* Wed Jul 25 2007 sbrabec@suse.cz
- Updated to version 0.2.3:
  * update wiki export script.
  * replaced rsa header files from rsalabs (official) with scute
    (open source).
  * allow CKR_USER_ALREADY_LOGGED_IN on C_Login.
  * mark internal functions as static.
  * add code to store public keys and generate keys.
- Name package according to shared library packaging policy.
* Fri Mar 30 2007 ro@suse.de
- added zlib-devel to buildreq
* Tue Oct  3 2006 sbrabec@suse.cz
- Updated to version 0.2.2:
  * bug fixes
  * code cleanup
* Fri May 12 2006 sbrabec@suse.cz
- New SuSE package, version 0.2.1.
